//
//  RoomDefines.h
//  zegoliveroom
//
//  Created by Strong on 2017/7/20.
//

#ifndef RoomDefines_h
#define RoomDefines_h

#include "./AVDefines.h"
#include <cstddef>

#ifndef ZEGO_API
    #ifdef WIN32
        #ifdef ZEGO_EXPORTS
            #define ZEGO_API __declspec(dllexport)
        #else
            #define ZEGO_API __declspec(dllimport)
        #endif
    #else
        #define ZEGO_API __attribute__((visibility("default")))
    #endif
#endif

namespace ZEGO
{
    namespace COMMON
    {
        /** 网络类型 */
        enum ZEGONetType
        {
            ZEGO_NT_NONE = 0,       /**< 无网络 */
            ZEGO_NT_LINE = 1,       /**< 有线网络 */
            ZEGO_NT_WIFI = 2,       /**< 无线网络 */
            ZEGO_NT_2G = 3,         /**< 2G网络 */
            ZEGO_NT_3G = 4,         /**< 3G网络 */
            ZEGO_NT_4G = 5,         /**< 4G网络 */
            ZEGO_NT_5G = 6,         /**< 5G网络 */
            ZEGO_NT_UNKNOWN = 32    /**< 未知网络 */
        };
        
        /** 流更新类型 */
        enum ZegoStreamUpdateType
        {
            StreamAdded     = 2001,     /**< 新增流 */
            StreamDeleted   = 2002,     /**< 删除流 */
        };

        enum ZegoStreamDeleteReason
        {
            ZEGO_DELETE_NOT_SUPPORT = -1,             /**< 无效值 */
            ZEGO_DELETE_NORMAL = 0,                   /**< 推流用户,正常关闭 */
            ZEGO_DELETE_HEARTBEAT_TIMEOUT = 1,        /**< 推流用户, 心跳超时,导致流关闭 */
            ZEGO_DELETE_REPEAT_LOGIN = 2,             /**< 推流用户,重复登录,导致流关闭 */
            ZEGO_DELETE_KICKOUT = 3,                  /**< 推流用户被T,导致流关闭 */
            ZEGO_DELETE_OFFLINE = 4,                  /**< 推流用户掉线,导致流关闭*/

            ZEGO_DELETE_SERVER = 100,                 /**< 推流用户的流,被服务器关闭*/
            ZEGO_DELETE_UNKOWN = 1000,                /**< 未知原因 (一般是由于SDK 未正常收到流删除推送导致)*/
        };

        struct ZegoStreamInfo
        {
            ZegoStreamInfo()
            {
                szUserId[0] = '\0';
                szUserName[0] = '\0';
                szStreamId[0] = '\0';
                szExtraInfo[0] = '\0';
                nStreamNId = 0;
                streamDeleteReason = ZEGO_DELETE_NOT_SUPPORT;
            }

            char szUserId[ZEGO_MAX_USERID_LEN];
            char szUserName[ZEGO_MAX_USERNAME_LEN];
            char szStreamId[ZEGO_MAX_COMMON_LEN];
            char szExtraInfo[ZEGO_MAX_EXTRA_INFO_LEN];
            int nStreamNId;

            //流删除原因,当前流删除原因 (只在sdk 回调onStreamUpdated 且type类型为流删除时有效) 
            ZegoStreamDeleteReason streamDeleteReason;
        };

        /** 发布直播的模式 */
        enum ZegoPublishFlag
        {
            ZEGO_JOIN_PUBLISH = 0,        /**< 连麦模式 */
            ZEGO_MIX_STREAM = 1 << 1,   /**< 混流模式 */
            ZEGO_SINGLE_ANCHOR = 1 << 2,   /**< 单主播模式 */
        };
        
        struct ZegoPublishingStreamInfo
        {
            ZegoPublishingStreamInfo()
            {
                uiRtmpURLCount = 0;
                uiHlsURLCount = 0;
                uiFlvURLCount = 0;
                for (int i = 0; i < ZEGO_MAX_URL_COUNT; i++)
                {
                    arrRtmpURLs[i] = NULL;
                    arrFlvURLs[i] = NULL;
                    arrHlsURLs[i] = NULL;
                }
            }
            const char* arrRtmpURLs[ZEGO_MAX_URL_COUNT];   /**< RTMP 播放 URL 列表 */
            unsigned int uiRtmpURLCount;                   /**< RTMP URL 个数 */
            
            const char* arrFlvURLs[ZEGO_MAX_URL_COUNT];
            unsigned int uiFlvURLCount;
            
            const char* arrHlsURLs[ZEGO_MAX_URL_COUNT];
            unsigned int uiHlsURLCount;
        };

        /** 成员角色 */
        enum ZegoRoomRole
        {
            UnknownRole = 0,/**< 未知角色 */
            Anchor = 1,     /**< 主播 */
            Audience = 2,   /**< 观众 */
            Assistant = 32, /**< 助教 */
        };

        /** 用户更新类型 */
        enum ZegoUserUpdateType
        {
            UPDATE_TOTAL = 1,   /**< 全量更新 */
            UPDATE_INCREASE,    /**< 增量更新 */
        };

        /** 用户更新属性 */
        enum ZegoUserUpdateFlag
        {
            USER_ADDED = 1,     /**< 新增 */
            USER_DELETED,       /**< 删除 */
        };

        struct ZegoUserInfo
        {
            ZegoUserInfo()
            {
                szUserId[0] = '\0';
                szUserName[0] = '\0';
                udapteFlag = USER_ADDED;
                role = UnknownRole;
            }

            char szUserId[ZEGO_MAX_USERID_LEN];
            char szUserName[ZEGO_MAX_USERNAME_LEN];
            ZegoUserUpdateFlag udapteFlag;
            ZegoRoomRole role;
        };

        struct ZegoRoomInfo
        {
            ZegoRoomInfo()
            {
                //标志房间时间断内唯一性的id
                uRoomSessionId = 0; 
            }

            unsigned long long uRoomSessionId;
        };
    }
}

#ifndef ZegoRoomDefines_h

namespace ZEGO
{
    namespace ROOM
    {
        struct ZegoUser
        {
            ZegoUser()
            {
                szUserId[0] = '\0';
                szUserName[0] = '\0';
            }

            char szUserId[ZEGO_MAX_USERID_LEN];
            char szUserName[ZEGO_MAX_USERNAME_LEN];
        };

        /** 消息类型 */
        enum ZegoMessageType
        {
            Text = 1,           /**< 文字 */
            Picture,            /**< 图片 */
            File,               /**< 文件 */
            OtherType = 100,    /**< 其他 */
        };

        /** 消息优先级 */
        enum ZegoMessagePriority
        {
            Default = 2,        /**< 默认优先级 */
            High = 3,           /**< 高优先级 */
        };

        /** 消息类别 */
        enum ZegoMessageCategory
        {
            Chat = 1,           /**< 聊天 */
            System,             /**< 系统 */
            Like,               /**< 点赞 */
            Gift,               /**< 送礼物 */
            OtherCategory = 100,/**< 其他 */
        };
        
        /** Relay类别 */
        enum ZegoRelayType
        {
            RelayTypeNone = 1,
            RelayTypeDati = 2,
        };

        struct ZegoRoomMessage
        {
            ZegoRoomMessage()
            {
                szUserId[0] = '\0';
                szUserName[0] = '\0';
                szContent[0] = '\0';
                role = COMMON::Audience;
                type = Text;
                priority = Default;
                category = Chat;
                sendTime = 0;
                messageId = 0;
            }

            char szUserId[ZEGO_MAX_USERID_LEN];
            char szUserName[ZEGO_MAX_USERNAME_LEN];
            COMMON::ZegoRoomRole role;
            char szContent[ZEGO_MAX_ROOMMESSAGE_LEN];
            unsigned long long messageId;
            ZegoMessageType type;
            ZegoMessagePriority priority;
            ZegoMessageCategory category;
            unsigned long long sendTime;
        };
        
        struct ZegoBigRoomMessage
        {
            ZegoBigRoomMessage()
            {
                szUserId[0] = '\0';
                szUserName[0] = '\0';
                szContent[0] = '\0';
                szMessageId[0] = '\0';
                role = COMMON::Audience;
                type = Text;
                category = Chat;
                sendTime = 0;
            }
            
            char szUserId[ZEGO_MAX_USERID_LEN];
            char szUserName[ZEGO_MAX_USERNAME_LEN];
            COMMON::ZegoRoomRole role;
            char szContent[ZEGO_MAX_ROOMMESSAGE_LEN];
            char szMessageId[ZEGO_MAX_IDENTITY_LEN];
            ZegoMessageType type;
            ZegoMessageCategory category;
            unsigned long long sendTime;
        };
        
        struct ZegoReliableMessage
        {
            /** 消息类型 */
            const char *type;
            /** 当前最新消息Seq */
            unsigned int latestSeq;
            /** 消息内容 */
            const char *content;
            /** 消息发送UserID */
            const char *userID;
            /** 消息发送UserName */
            const char *userName;
            /** 发送时间 */
            unsigned long long sendTime;

            ZegoReliableMessage()
            {
                type = NULL;
                latestSeq = 0;
                content = NULL;
                userID = NULL;
                userName = NULL;
                sendTime = 0;
            }
        };
        
        struct ZegoReliableMessageInfo
        {
            /** 消息类型 */
            const char *type;
            /** 当前最新消息Seq */
            unsigned int latestSeq;

            ZegoReliableMessageInfo()
            {
                type = NULL;
                latestSeq = 0;
            }
        };

        struct ZegoRoomExtraInfo
        {
            ZegoRoomExtraInfo()
            {
                szKey[0] = '\0';
                szValue[0] = '\0';
                szUserID[0] = '\0';
                szUserName[0] = '\0';
                updateTime = 0;
            }
            /** 附加信息key */
            char szKey[ZEGO_MAX_ROOM_EXTRA_INFO_KEY_LEN];
            /** 附加信息值 */
            char szValue[ZEGO_MAX_ROOM_EXTRA_INFO_VALUE_LEN];
            /**  变更附加信息UserID */
            char szUserID[ZEGO_MAX_USERID_LEN];
            /** 变更附加信息UserName */
            char szUserName[ZEGO_MAX_USERNAME_LEN];
            /** 变更附加信息时间 */
            unsigned long long updateTime;
        };
    
        enum ZegoConnectState
        {
            Disconnected = 1,
            WaitingConnect,
            Connecting,
            Connected,
        };
    

        enum PushStreamState
        {
            PUSH_STREAM_OK = 1,  //推流成功
            PUSH_STREAM_FAIL = 2, //推流失败
            PUSH_STREAM_BROKEN = 3,//推流中断
            PUSH_STREAM_RECONN_OK = 4, //推流成功
            PUSH_STREAM_STOP = 5                  //停止推流
        };
    
    
    
    }
}

#endif  /* ZegoRoomDefines_h */
#endif /* RoomDefines_h */


